PdfGrid class

A table (grid) element that can be drawn on a PDF page.

Example:

final grid = PdfGrid();
grid.columns.add(count: 3);
final row = grid.rows.add();
row.cells[0].value = 'Name';
row.cells[1].value = 'Age';
row.cells[2].value = 'City';
grid.draw(page.graphics, bounds: Rect.fromLTWH(50, 100, 500, 0));

Constructors

PdfGrid()

Properties

columns PdfGridColumnCollection
final
hashCode int
The hash code for this object.
no setterinherited
headers PdfGridHeaderCollection
final
rows PdfGridRowCollection
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style PdfGridStyle
getter/setter pair

Methods

draw(PdfGraphics graphics, {required Rect bounds}) double
Draw the grid on the given graphics at the specified bounds. Returns the total height used.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited