PdfGridCellStyle class

Cell style.

Constructors

PdfGridCellStyle()

Properties

backgroundBrush PdfBrush?
getter/setter pair
borderPen PdfPen?
getter/setter pair
font PdfFont?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringFormat PdfStringFormat?
getter/setter pair
textBrush PdfBrush?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited