PdfGridRow class

A single row in the grid.

Constructors

PdfGridRow()

Properties

cells List<PdfGridCell>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style PdfGridRowStyle?
getter/setter pair

Methods

ensureCells(int count) → void
Ensure the row has enough cells for the given column count.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited