PdfOrderedList class

An ordered (numbered) list element.

Constructors

PdfOrderedList({required List<String> items, PdfFont? font, PdfBrush? textBrush, double indent = 20, double itemSpacing = 4})

Properties

font PdfFont?
final
hashCode int
The hash code for this object.
no setterinherited
indent double
final
items List<String>
final
itemSpacing double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textBrush PdfBrush?
final

Methods

draw(PdfGraphics graphics, {required Rect bounds}) double
Draw the list and return total height used.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited