PdfPath class

Represents a Bezier path for drawing complex shapes.

Constructors

PdfPath()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addEllipse(double x, double y, double width, double height) → void
Add an ellipse approximated by Bezier curves.
addRectangle(double x, double y, double width, double height) → void
Add a rectangle to the path.
closePath() → void
Close the current subpath.
curveTo(double x1, double y1, double x2, double y2, double x3, double y3) → void
Draw a cubic Bezier curve.
lineTo(double x, double y) → void
Draw a line to a point.
moveTo(double x, double y) → void
Move to a point without drawing.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toOperators() String
Convert path to PDF content stream operators.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited