PdfString class

PDF String (literal or hexadecimal).

Inheritance

Constructors

PdfString(String value, {bool hex = false})
PdfString.fromBytes(Uint8List bytes)
Create from raw bytes as hex string.

Properties

hashCode int
The hash code for this object.
no setterinherited
hex bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
writeTo(StringBuffer buffer) → void
Serialize this object to PDF syntax bytes.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited