PdfToken class

A single token from the PDF byte stream.

Constructors

PdfToken(PdfTokenType type, dynamic value, int offset)

Properties

hashCode int
The hash code for this object.
no setterinherited
offset int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type PdfTokenType
final
value → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited