PdfTokenizer class

Low-level lexer for PDF byte streams.

Reads raw PDF bytes and produces a stream of PdfTokens.

Constructors

PdfTokenizer(Uint8List _data)

Properties

hashCode int
The hash code for this object.
no setterinherited
isEof bool
Whether we've reached the end.
no setter
length int
Total number of bytes.
no setter
position int
Current byte position.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

findForward(String needle, [int start = 0]) int?
Find the byte offset of a string searching forward from start.
findLast(String needle) int?
Find the byte offset of a string searching backwards from the end.
nextToken() PdfToken
Read the next token.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readBytes(int count) Uint8List
Read raw bytes from current position.
readLine() String
Read a line of text from the current position.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited