PdfBitmap class
Represents a bitmap image (JPEG or PNG) for embedding in PDF.
Constructors
- PdfBitmap(Uint8List _data)
- Create from raw image bytes (JPEG or PNG).
- PdfBitmap.fromBase64(String base64Data)
-
Create from a base64-encoded string.
factory
Properties
- hasAlpha → bool
-
Whether the image has an alpha channel.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ int
-
latefinal
- imageData → Uint8List
-
Get the raw image data.
no setter
- isJpeg → bool
-
Whether this is a JPEG.
no setter
- isPng → bool
-
Whether this is a PNG.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width ↔ int
-
latefinal
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toImageStream(
) → PdfStream - Build the PDF image XObject stream.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited